import { LitElement, css, html } from 'lit';
import { property, customElement } from 'lit/decorators.js';
import { unsafeHTML } from 'lit/directives/unsafe-html.js'
import { Relay } from 'nostr-tools';
import {marked} from 'marked';

import '@shoelace-style/shoelace/dist/components/card/card.js';
import '@shoelace-style/shoelace/dist/components/button/button.js';

import { styles } from '../styles/shared-styles';




@customElement('note-wall')
export class NoteWall extends LitElement {

@property({ type: Array }) notes: { content: string; date: string }[] = [];
@property({ type: String }) relayName: string = '';


note = ''; // store notes

  static styles = [
    styles,
    css`


.comment-wall table {
  margin: auto;
  margin-bottom: 50px;
}


.comment-wall th {
  vertical-align: top;
}

.comment-wall td {
  vertical-align: top;
  width: 600px;
  padding: 3px;
}

#add-comment {
  text-align: right;
  margin-right: 10px;
  margin-bottom: 5px;
}

.note-content {
        text-align: left;
        white-space: pre-wrap;
      }
      .note-content img {
        max-width: 100%;
        height: auto;
      }
  `];



  getUserLang() {

    return navigator.language || 'en';

  }

  async firstUpdated() {
    // this method is a lifecycle even in lit
    // for more info check out the lit docs https://lit.dev/docs/components/lifecycle/
    console.log('Here are some recent notes from the neighborhood');
  }

  async connectedCallback(): Promise<void> {
    super.connectedCallback();
  await Promise.all([
    this.fetchNotes(),

  ]);

}


/* async translateText(text: string, targetLang: string) {
  try {
    const response = await axios.post('https://api-free.deepl.com/v2/translate', {
      text, target_lang: targetLang });

    return response.data.translations[0].text;  // Assuming DeepL's API structure
  } catch (error: any) {
    console.error('Error during translation:', error.response?.data || error.message);
    return '';
  }
} */




async fetchNotes() {
 // const ifcaRelay = await Relay.connect('wss://hi.myvoiceourstory.org');

  const migsRelay = await Relay.connect('wss://notes.miguelalmodo.com');
  console.log(`connected to ${migsRelay.url}`);


// store the relay name
  this.relayName = migsRelay.url;


  const sub = migsRelay.subscribe([
    {
      kinds: [30023], // short and long form notes
      limit: 5,
    }
  ], {
    onevent: async (event) => {
      console.log('Event received:', event);
      this.notes = [...this.notes, {
        content: event.content,
        date: new Date(event.created_at * 1000).toLocaleDateString(),
      }];
      this.requestUpdate();
      console.log(migsRelay)

    },
    oneose: () => {
      sub.close();
      this.requestUpdate();
    },
  });

}

async displayLongNotes() {

}




  share() {
    if ((navigator as any).share) {
      (navigator as any).share({
        title: 'Nostr Micro Client',
        text: 'Share this with your homie!',
        url: 'https://miguelalmodo.com/',
      });
    }
  }

  render() {
    return html`
      <app-header ?enableBack="${true}"></app-header>
      <main>
        <div id="welcomeBar">
          <sl-card id="WelcomeCard">
            <section>
              <header class="">
                <h2 class="">
                  Recent Notes from ${this.relayName}
                </h2>
              </header>
              <table class="comment-wall">
                ${this.notes.map(
                  (note) => html`
                    <tr>
                      <td>
                        <h3>${note.date}</h3>
                      </td>
                      <td class="note-content">
                        ${unsafeHTML(marked(note.content) as string)}
                      </td>
                    </tr>
                  `
                )}
              </table>
            </section>
          </sl-card>
        </div>
      </main>
    `;
  }
}
